#!/bin/sh
# Copyright Julián Marcos — EPLv2
# Texts

RELIST_ACT="*AA: Listar de nuevo. (Re-chequea los estados)"
EXIT_ACT="*AB: Salir"
FILTER_ACT="*AC: Filtrar"

BLOCK_ACT="Bloquear"
REJECT_ACT="Quitar"
ALLOW_ACT="Permitir"

EXIT="Salir"

YES="Sí"
NO="No"

FILTER_BASED_ON="Filtrar basado en"
FILTER_DENIED="Denegados"
FILTER_ALLOWED="Permitidos"
CHOOSE="Elegir"
CHOOSE_DEVICE="$CHOOSE dispositivo"
CHOOSE_ACTION="$CHOOSE acción"
APPLY_PERMANENTLY="¿Aplicar permanentemente?"

NO_DEVICE_CHOSEN="No has elegido ningún dispositivo"
NO_ACTION_CHOSEN="No has elegido ninguna acción"
INVALID_ACTION="Acción invalida"

# Options
PERMANENT_TOGGLE="0"
SCRIPT_NAME="$(basename "$0")"


usbguard() {
	#shellcheck disable=SC2068
	doas /usr/bin/usbguard $@
}
notify_exit() {
	notify-send "$SCRIPT_NAME" "$1"
	exit 1
}

filtrar_opt() {
based_on="$(rofi -dmenu -p "$FILTER_BASED_ON"<<EoF
$FILTER_DENIED
$FILTER_ALLOWED
EoF
)"
case "$based_on" in
"$FILTER_ALLOWED") based_on="allow";;
"$FILTER_DENIED") based_on="block";;
esac
exec "$0" "$based_on"
}

chosen="$(rofi -dmenu -p "$CHOOSE_DEVICE"<<EoF
$(usbguard list-devices|grep "$1")
$RELIST_ACT
$EXIT_ACT
$FILTER_ACT
EoF
)"
case "$chosen" in
	"") notify_exit "$NO_DEVICE_CHOSEN";;
	"$EXIT_ACT") exit;;
	"$EXIT") exit;;
	"$FILTER_ACT") filtrar_opt;;
	"$RELIST_ACT") exec $0 "$1";;
esac
id="$(echo "$chosen" | cut -d: -f1)"

action="$(rofi -dmenu -p "$CHOOSE_ACTION" <<EoF
$ALLOW_ACT
$BLOCK_ACT
$REJECT_ACT
$EXIT
EoF
)"
case "$action" in
	"") notify_exit "$NO_ACTION_CHOSEN";;
	"$ALLOW_ACT") CMD="allow-device";;
	"$BLOCK_ACT") CMD="block-device";;
	"$EXIT") exit;;
	"$REJECT_ACT") CMD="reject-device";;
	*) notify_exit_invalid_param "$INVALID_ACTION: $action";;
esac

permanent_opt="--"
[ "$PERMANENT_TOGGLE" = "1" ] && {
	permanent="$(rofi -dmenu -p "$APPLY_PERMANENTLY" <<EoF
$NO
$YES
$EXIT
EoF
	)"
	case "$permanent" in
		"$YES") permanent_opt="-p";;
		"$EXIT") exit;;
		*) permanent_opt="--";;
	esac
}

usbguard "$CMD" "$permanent_opt" "$id"